==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/change/vo/ChangeconsdrawbudgetVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordconsdrawbudgetVO;
import com.ejianc.business.record.vo.RecordconsdrawbudgetdetailVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 施工预算图变更
 * 
 * @author generator
 * 
 */
public class ChangeconsdrawbudgetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long consdrawbudgetId; // 施工图预算id
    private java.math.BigDecimal conDrawBudgetTotal; // 施工图预算合计
    private java.lang.Integer isOpenControl; // 是否开启控制:0 否，1:是
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.math.BigDecimal provisionalEstimateTotal; // 暂估价合计
    private java.lang.String billCode; // 单据编码
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.Long sort; // 序号
    
    private List<ChangeconsdrawbudgetdetailVO> changeconsdrawbudgetdetailEntities = new ArrayList<>(); // 施工图预算变更子表
    private List<RecordconsdrawbudgetdetailVO> recordconsdrawbudgetdetailVOS = new ArrayList<>(); //变更记录历史信息

    public List<RecordconsdrawbudgetdetailVO> getRecordconsdrawbudgetdetailVOS() {
        return recordconsdrawbudgetdetailVOS;
    }

    public void setRecordconsdrawbudgetdetailVOS(List<RecordconsdrawbudgetdetailVO> recordconsdrawbudgetdetailVOS) {
        this.recordconsdrawbudgetdetailVOS = recordconsdrawbudgetdetailVOS;
    }



    /**
     * 施工图预算id
     */
    public java.lang.Long getConsdrawbudgetId() {
        return consdrawbudgetId;
    }

    /**
     * 施工图预算id
     */
    public void setConsdrawbudgetId(java.lang.Long consdrawbudgetId) {
        this.consdrawbudgetId = consdrawbudgetId;
    }
    /**
     * 施工图预算合计
     */
    public java.math.BigDecimal getConDrawBudgetTotal() {
        return conDrawBudgetTotal;
    }

    /**
     * 施工图预算合计
     */
    public void setConDrawBudgetTotal(java.math.BigDecimal conDrawBudgetTotal) {
        this.conDrawBudgetTotal = conDrawBudgetTotal;
    }
    /**
     * 是否开启控制:0 否，1:是
     */
    public java.lang.Integer getIsOpenControl() {
        return isOpenControl;
    }

    /**
     * 是否开启控制:0 否，1:是
     */
    public void setIsOpenControl(java.lang.Integer isOpenControl) {
        this.isOpenControl = isOpenControl;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 暂估价合计
     */
    public java.math.BigDecimal getProvisionalEstimateTotal() {
        return provisionalEstimateTotal;
    }

    /**
     * 暂估价合计
     */
    public void setProvisionalEstimateTotal(java.math.BigDecimal provisionalEstimateTotal) {
        this.provisionalEstimateTotal = provisionalEstimateTotal;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    @ReferDeserialTransfer
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    
     /**
      * 施工图预算变更子表
      */
     public List<ChangeconsdrawbudgetdetailVO> getChangeconsdrawbudgetdetailEntities() {
        return changeconsdrawbudgetdetailEntities;
     }

     /**
      * 施工图预算变更子表
      */
     public void setChangeconsdrawbudgetdetailEntities(List<ChangeconsdrawbudgetdetailVO> changeconsdrawbudgetdetailEntities) {
        this.changeconsdrawbudgetdetailEntities = changeconsdrawbudgetdetailEntities;
     }
}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/change/vo/ChangeconsdrawbudgetVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordconsdrawbudgetVO;
import com.ejianc.business.record.vo.RecordconsdrawbudgetdetailVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 施工预算图变更
 * 
 * @author generator
 * 
 */
public class ChangeconsdrawbudgetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long consdrawbudgetId; // 施工图预算id
    private java.math.BigDecimal conDrawBudgetTotal; // 施工图预算合计
    private java.lang.Integer isOpenControl; // 是否开启控制:0 否，1:是
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.math.BigDecimal provisionalEstimateTotal; // 暂估价合计
    private java.lang.String billCode; // 单据编码
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.Long sort; // 序号
    
    private List<ChangeconsdrawbudgetdetailVO> consdrawbudgetdetailEntities = new ArrayList<>(); // 施工图预算变更子表
    private List<RecordconsdrawbudgetdetailVO> recordconsdrawbudgetdetailVOS = new ArrayList<>(); //变更记录历史信息

    public List<RecordconsdrawbudgetdetailVO> getRecordconsdrawbudgetdetailVOS() {
        return recordconsdrawbudgetdetailVOS;
    }

    public void setRecordconsdrawbudgetdetailVOS(List<RecordconsdrawbudgetdetailVO> recordconsdrawbudgetdetailVOS) {
        this.recordconsdrawbudgetdetailVOS = recordconsdrawbudgetdetailVOS;
    }



    /**
     * 施工图预算id
     */
    public java.lang.Long getConsdrawbudgetId() {
        return consdrawbudgetId;
    }

    /**
     * 施工图预算id
     */
    public void setConsdrawbudgetId(java.lang.Long consdrawbudgetId) {
        this.consdrawbudgetId = consdrawbudgetId;
    }
    /**
     * 施工图预算合计
     */
    public java.math.BigDecimal getConDrawBudgetTotal() {
        return conDrawBudgetTotal;
    }

    /**
     * 施工图预算合计
     */
    public void setConDrawBudgetTotal(java.math.BigDecimal conDrawBudgetTotal) {
        this.conDrawBudgetTotal = conDrawBudgetTotal;
    }
    /**
     * 是否开启控制:0 否，1:是
     */
    public java.lang.Integer getIsOpenControl() {
        return isOpenControl;
    }

    /**
     * 是否开启控制:0 否，1:是
     */
    public void setIsOpenControl(java.lang.Integer isOpenControl) {
        this.isOpenControl = isOpenControl;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 暂估价合计
     */
    public java.math.BigDecimal getProvisionalEstimateTotal() {
        return provisionalEstimateTotal;
    }

    /**
     * 暂估价合计
     */
    public void setProvisionalEstimateTotal(java.math.BigDecimal provisionalEstimateTotal) {
        this.provisionalEstimateTotal = provisionalEstimateTotal;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    @ReferDeserialTransfer
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }

    public List<ChangeconsdrawbudgetdetailVO> getConsdrawbudgetdetailEntities() {
        return consdrawbudgetdetailEntities;
    }

    public void setConsdrawbudgetdetailEntities(List<ChangeconsdrawbudgetdetailVO> consdrawbudgetdetailEntities) {
        this.consdrawbudgetdetailEntities = consdrawbudgetdetailEntities;
    }
}
